@@ -5,7 +5,7 @@ from bgeditor.dao.FFmpeg import create_source_can_loop, create_loop
 from bgeditor.dao.Lyric import Lyric
 from bgeditor.common.utils import download_file, get_dir
 import tempfile
-from bgeditor.dao.Component import create_video
+from bgeditor.dao.Component import create_video, create_image
 
 class BGEditor():
     def __init__(self):
@@ -39,6 +39,11 @@ class BGEditor():
         path_vid = os.path.join(get_dir('results'), "final-vid-" + str(uuid.uuid4()) + ".mp4")
         path_vid = create_video(list_comp_data, path_vid, job_id, mf_server)
         return path_vid
+    def create_image_json(self, list_comp_data):
+        #path_vid = self.root_dir.name + "/final-vid-" + str(uuid.uuid4()) + ".avi"
+        path_vid = os.path.join(get_dir('results'), "final-image-" + str(uuid.uuid4()) + ".png")
+        path_vid = create_image(list_comp_data, path_vid, 0)
+        return path_vid
 
     def close(self):
         os.system("rm -rf /tmp/download/*")
