@@ -13,8 +13,8 @@ def upload_file_old(path):
     return Client("/u02/drive_config/public_config/coca_idrive.json", "upload", path, "").upload_file(file_name, path, public_folder_id)
 def upload_file(path):
     dh = DriverHelper()
-    x = dh.upload_file("result@soundhex.com", path)
-    return x.replace("gdrive;;result@soundhex.com;;","")
+    x = dh.upload_file_auto("studio-result", [path])
+    return x[0].split(";;")[-1]
 def remove(path):
     try:
         os.remove(path)
