@@ -5,15 +5,20 @@ import uuid,json, shutil,os
 from moviepy.editor import *
 import subprocess
 import urllib
-def download_audio(url,ext='mp3'):
-    file_name = str(uuid.uuid4()) + "." + ext
-    rs = os.path.join(get_dir('download'), file_name)
-    ydl_opts = {
-        'outtmpl': rs,
-        'format': 'bestaudio/m4a',
-    }
-    with youtube_dl.YoutubeDL(ydl_opts) as ydl:
-        ydl.download([url])
+def download_audio(url, ext='mp3', retries= 3):
+    try:
+        file_name = str(uuid.uuid4()) + "." + ext
+        rs = os.path.join(get_dir('download'), file_name)
+        ydl_opts = {
+            'outtmpl': rs,
+            'format': 'bestaudio/m4a',
+        }
+        with youtube_dl.YoutubeDL(ydl_opts) as ydl:
+            ydl.download([url])
+    except Exception:
+        if(retries<0):
+            raise
+        return download_audio(url, ext, retries-1)
     return rs
 def create_lyric_outro_songs(deezer_artist_id, lyric_outro_repeat, retries=3):
     if deezer_artist_id == 977996688:
